summaryrefslogtreecommitdiffstats
path: root/libkdegames/kgameprogress.h
diff options
context:
space:
mode:
Diffstat (limited to 'libkdegames/kgameprogress.h')
-rw-r--r--libkdegames/kgameprogress.h58
1 files changed, 29 insertions, 29 deletions
diff --git a/libkdegames/kgameprogress.h b/libkdegames/kgameprogress.h
index d6a353ac..d4cebe7b 100644
--- a/libkdegames/kgameprogress.h
+++ b/libkdegames/kgameprogress.h
@@ -24,13 +24,13 @@
#ifndef _KPROGRES_H
#define _KPROGRES_H "$Id$"
-#include <qframe.h>
-#include <qrangecontrol.h>
+#include <tqframe.h>
+#include <tqrangecontrol.h>
#include <kdemacros.h>
/**
* @short A progress indicator widget.
*
* KGameProgress is derived from QFrame and QRangeControl, so
* you can use all the methods from those classes. The only difference
* is that setValue() is now made a slot, so you can connect
* stuff to it.
@@ -47,14 +47,14 @@
* @author Martynas Kunigelis
* @version $Id$
*/
-class KDE_EXPORT KGameProgress : public QFrame, public QRangeControl
+class KDE_EXPORT KGameProgress : public TQFrame, public QRangeControl
{
Q_OBJECT
Q_ENUMS( BarStyle )
Q_PROPERTY( int value READ value WRITE setValue)
Q_PROPERTY( BarStyle barStyle READ barStyle WRITE setBarStyle )
- Q_PROPERTY( QColor barColor READ barColor WRITE setBarColor )
- Q_PROPERTY( QPixmap barPixmap READ barPixmap WRITE setBarPixmap )
+ Q_PROPERTY( TQColor barColor READ barColor WRITE setBarColor )
+ Q_PROPERTY( TQPixmap barPixmap READ barPixmap WRITE setBarPixmap )
Q_PROPERTY( Orientation orientation READ orientation WRITE setOrientation )
Q_PROPERTY( bool textEnabled READ textEnabled WRITE setTextEnabled )
@@ -70,18 +70,18 @@ public:
/**
* Construct a horizontal progress bar.
*/
- KGameProgress(QWidget *parent=0, const char *name=0);
+ KGameProgress(TQWidget *parent=0, const char *name=0);
/**
* Construct a progress bar with orientation @p orient.
*/
- KGameProgress(Orientation orient, QWidget *parent=0, const char *name=0);
+ KGameProgress(Orientation orient, TQWidget *parent=0, const char *name=0);
/**
* Construct a progress bar with minimum, maximum and initial values.
*/
KGameProgress(int minValue, int maxValue, int value, Orientation,
- QWidget *parent=0, const char *name=0);
+ TQWidget *parent=0, const char *name=0);
/**
* Destruct the progress bar.
@@ -98,12 +98,12 @@ public:
/**
* Set the color of the progress bar.
*/
- void setBarColor(const QColor &);
+ void setBarColor(const TQColor &);
/**
* Set a pixmap to be shown in the progress bar.
*/
- void setBarPixmap(const QPixmap &);
+ void setBarPixmap(const TQPixmap &);
/**
* Set the orientation of the progress bar.
@@ -129,21 +129,21 @@ public:
* Retrieve the bar color.
* @see setBarColor()
*/
- const QColor &barColor() const;
+ const TQColor &barColor() const;
/**
* Retrieve the bar pixmap.
*
* @see setBarPixmap()
*/
- const QPixmap *barPixmap() const;
+ const TQPixmap *barPixmap() const;
/**
* Retrive the current status
*
* @see setValue()
*/
- int value() const { return QRangeControl::value(); }
+ int value() const { return TQRangeControl::value(); }
/**
* Retrive the orientation of the progress bar.
*
@@ -161,21 +161,21 @@ public:
/**
*/
- virtual QSize sizeHint() const;
+ virtual TQSize sizeHint() const;
/**
*/
- virtual QSize minimumSizeHint() const;
+ virtual TQSize minimumSizeHint() const;
/**
*/
- virtual QSizePolicy sizePolicy() const;
+ virtual TQSizePolicy sizePolicy() const;
/**
* Retrieve the current format for printing status text.
* @see setFormat()
*/
- QString format() const;
+ TQString format() const;
public slots:
@@ -187,7 +187,7 @@ public slots:
* @param format %p is replaced by percentage done, %v is replaced by actual
* value, %m is replaced by the maximum value.
*/
- void setFormat(const QString & format);
+ void setFormat(const TQString & format);
/**
* Set the current value of the progress bar to @p value.
@@ -220,31 +220,31 @@ protected:
void rangeChange();
/**
*/
- void styleChange( QStyle& );
+ void styleChange( TQStyle& );
/**
*/
- void paletteChange( const QPalette & );
+ void paletteChange( const TQPalette & );
/**
*/
- void drawContents( QPainter * );
+ void drawContents( TQPainter * );
private slots:
void paletteChange();
private:
- QPixmap *bar_pixmap;
+ TQPixmap *bar_pixmap;
bool use_supplied_bar_color;
- QColor bar_color;
- QColor bar_text_color;
- QColor text_color;
- QRect fr;
+ TQColor bar_color;
+ TQColor bar_text_color;
+ TQColor text_color;
+ TQRect fr;
BarStyle bar_style;
Orientation orient;
bool text_enabled;
- QString format_;
+ TQString format_;
void initialize();
int recalcValue(int);
- void drawText(QPainter *);
+ void drawText(TQPainter *);
void adjustStyle();
class KGameProgressPrivate;
@@ -24,13 +24,13 @@
* @short A progress indicator widget.
*
- * KGameProgress is derived from QFrame and QRangeControl, so
+ * KGameProgress is derived from TQFrame and TQRangeControl, so
* you can use all the methods from those classes. The only difference
* is that setValue() is now made a slot, so you can connect